# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetSecurityGovernanceRuleResult',
    'AwaitableGetSecurityGovernanceRuleResult',
    'get_security_governance_rule',
    'get_security_governance_rule_output',
]

@pulumi.output_type
class GetSecurityGovernanceRuleResult:
    """
    A collection of values returned by getSecurityGovernanceRule.
    """
    def __init__(__self__, condition_ids=None, description=None, id=None, is_enabled=None, name=None, org_id=None, project_id=None, tags=None, time_windows=None, user_group_ids=None):
        if condition_ids and not isinstance(condition_ids, list):
            raise TypeError("Expected argument 'condition_ids' to be a list")
        pulumi.set(__self__, "condition_ids", condition_ids)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if is_enabled and not isinstance(is_enabled, bool):
            raise TypeError("Expected argument 'is_enabled' to be a bool")
        pulumi.set(__self__, "is_enabled", is_enabled)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if time_windows and not isinstance(time_windows, list):
            raise TypeError("Expected argument 'time_windows' to be a list")
        pulumi.set(__self__, "time_windows", time_windows)
        if user_group_ids and not isinstance(user_group_ids, list):
            raise TypeError("Expected argument 'user_group_ids' to be a list")
        pulumi.set(__self__, "user_group_ids", user_group_ids)

    @_builtins.property
    @pulumi.getter(name="conditionIds")
    def condition_ids(self) -> Sequence[_builtins.str]:
        """
        List of condition IDs associated with the rule.
        """
        return pulumi.get(self, "condition_ids")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        The description of the rule.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def id(self) -> Optional[_builtins.str]:
        """
        The ID of the rule.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="isEnabled")
    def is_enabled(self) -> _builtins.bool:
        """
        Whether the rule is enabled.
        """
        return pulumi.get(self, "is_enabled")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        The name of the rule.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> _builtins.str:
        """
        The organization identifier.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> _builtins.str:
        """
        The project identifier.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Sequence[_builtins.str]:
        """
        Tags associated with the rule.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="timeWindows")
    def time_windows(self) -> Sequence['outputs.GetSecurityGovernanceRuleTimeWindowResult']:
        """
        Time windows when the rule is active.
        """
        return pulumi.get(self, "time_windows")

    @_builtins.property
    @pulumi.getter(name="userGroupIds")
    def user_group_ids(self) -> Sequence[_builtins.str]:
        """
        List of user group IDs associated with the rule.
        """
        return pulumi.get(self, "user_group_ids")


class AwaitableGetSecurityGovernanceRuleResult(GetSecurityGovernanceRuleResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSecurityGovernanceRuleResult(
            condition_ids=self.condition_ids,
            description=self.description,
            id=self.id,
            is_enabled=self.is_enabled,
            name=self.name,
            org_id=self.org_id,
            project_id=self.project_id,
            tags=self.tags,
            time_windows=self.time_windows,
            user_group_ids=self.user_group_ids)


def get_security_governance_rule(id: Optional[_builtins.str] = None,
                                 name: Optional[_builtins.str] = None,
                                 org_id: Optional[_builtins.str] = None,
                                 project_id: Optional[_builtins.str] = None,
                                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSecurityGovernanceRuleResult:
    """
    Data source for retrieving a Harness Chaos Security Governance Rule.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    # Data sources to verify the rules
    example = harness.chaos.get_security_governance_rule(id="<rule_id>",
        org_id="<org_id>",
        project_id="<project_id>")
    example_linux = harness.chaos.get_security_governance_rule(id="<rule_id>",
        org_id="<org_id>",
        project_id="<project_id>")
    example_windows = harness.chaos.get_security_governance_rule(id="<rule_id>",
        org_id="<org_id>",
        project_id="<project_id>")
    ```


    :param _builtins.str id: The ID of the rule.
    :param _builtins.str name: The name of the rule.
    :param _builtins.str org_id: The organization identifier.
    :param _builtins.str project_id: The project identifier.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:chaos/getSecurityGovernanceRule:getSecurityGovernanceRule', __args__, opts=opts, typ=GetSecurityGovernanceRuleResult).value

    return AwaitableGetSecurityGovernanceRuleResult(
        condition_ids=pulumi.get(__ret__, 'condition_ids'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        is_enabled=pulumi.get(__ret__, 'is_enabled'),
        name=pulumi.get(__ret__, 'name'),
        org_id=pulumi.get(__ret__, 'org_id'),
        project_id=pulumi.get(__ret__, 'project_id'),
        tags=pulumi.get(__ret__, 'tags'),
        time_windows=pulumi.get(__ret__, 'time_windows'),
        user_group_ids=pulumi.get(__ret__, 'user_group_ids'))
def get_security_governance_rule_output(id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                        name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                        org_id: Optional[pulumi.Input[_builtins.str]] = None,
                                        project_id: Optional[pulumi.Input[_builtins.str]] = None,
                                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetSecurityGovernanceRuleResult]:
    """
    Data source for retrieving a Harness Chaos Security Governance Rule.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    # Data sources to verify the rules
    example = harness.chaos.get_security_governance_rule(id="<rule_id>",
        org_id="<org_id>",
        project_id="<project_id>")
    example_linux = harness.chaos.get_security_governance_rule(id="<rule_id>",
        org_id="<org_id>",
        project_id="<project_id>")
    example_windows = harness.chaos.get_security_governance_rule(id="<rule_id>",
        org_id="<org_id>",
        project_id="<project_id>")
    ```


    :param _builtins.str id: The ID of the rule.
    :param _builtins.str name: The name of the rule.
    :param _builtins.str org_id: The organization identifier.
    :param _builtins.str project_id: The project identifier.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:chaos/getSecurityGovernanceRule:getSecurityGovernanceRule', __args__, opts=opts, typ=GetSecurityGovernanceRuleResult)
    return __ret__.apply(lambda __response__: GetSecurityGovernanceRuleResult(
        condition_ids=pulumi.get(__response__, 'condition_ids'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        is_enabled=pulumi.get(__response__, 'is_enabled'),
        name=pulumi.get(__response__, 'name'),
        org_id=pulumi.get(__response__, 'org_id'),
        project_id=pulumi.get(__response__, 'project_id'),
        tags=pulumi.get(__response__, 'tags'),
        time_windows=pulumi.get(__response__, 'time_windows'),
        user_group_ids=pulumi.get(__response__, 'user_group_ids')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetInfraModuleTestingResult',
    'AwaitableGetInfraModuleTestingResult',
    'get_infra_module_testing',
    'get_infra_module_testing_output',
]

@pulumi.output_type
class GetInfraModuleTestingResult:
    """
    A collection of values returned by getInfraModuleTesting.
    """
    def __init__(__self__, account=None, created=None, description=None, git_tag_style=None, id=None, module_error=None, module_id=None, name=None, org=None, pipelines=None, project=None, provider_connector=None, provisioner_type=None, provisioner_version=None, release_pipeline=None, repository=None, repository_branch=None, repository_commit=None, repository_connector=None, repository_path=None, repository_url=None, synced=None, system=None, tags=None, testing_enabled=None, testing_metadata=None, updated=None, versions=None):
        if account and not isinstance(account, str):
            raise TypeError("Expected argument 'account' to be a str")
        pulumi.set(__self__, "account", account)
        if created and not isinstance(created, int):
            raise TypeError("Expected argument 'created' to be a int")
        pulumi.set(__self__, "created", created)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if git_tag_style and not isinstance(git_tag_style, str):
            raise TypeError("Expected argument 'git_tag_style' to be a str")
        pulumi.set(__self__, "git_tag_style", git_tag_style)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if module_error and not isinstance(module_error, str):
            raise TypeError("Expected argument 'module_error' to be a str")
        pulumi.set(__self__, "module_error", module_error)
        if module_id and not isinstance(module_id, str):
            raise TypeError("Expected argument 'module_id' to be a str")
        pulumi.set(__self__, "module_id", module_id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if org and not isinstance(org, str):
            raise TypeError("Expected argument 'org' to be a str")
        pulumi.set(__self__, "org", org)
        if pipelines and not isinstance(pipelines, list):
            raise TypeError("Expected argument 'pipelines' to be a list")
        pulumi.set(__self__, "pipelines", pipelines)
        if project and not isinstance(project, str):
            raise TypeError("Expected argument 'project' to be a str")
        pulumi.set(__self__, "project", project)
        if provider_connector and not isinstance(provider_connector, str):
            raise TypeError("Expected argument 'provider_connector' to be a str")
        pulumi.set(__self__, "provider_connector", provider_connector)
        if provisioner_type and not isinstance(provisioner_type, str):
            raise TypeError("Expected argument 'provisioner_type' to be a str")
        pulumi.set(__self__, "provisioner_type", provisioner_type)
        if provisioner_version and not isinstance(provisioner_version, str):
            raise TypeError("Expected argument 'provisioner_version' to be a str")
        pulumi.set(__self__, "provisioner_version", provisioner_version)
        if release_pipeline and not isinstance(release_pipeline, str):
            raise TypeError("Expected argument 'release_pipeline' to be a str")
        pulumi.set(__self__, "release_pipeline", release_pipeline)
        if repository and not isinstance(repository, str):
            raise TypeError("Expected argument 'repository' to be a str")
        pulumi.set(__self__, "repository", repository)
        if repository_branch and not isinstance(repository_branch, str):
            raise TypeError("Expected argument 'repository_branch' to be a str")
        pulumi.set(__self__, "repository_branch", repository_branch)
        if repository_commit and not isinstance(repository_commit, str):
            raise TypeError("Expected argument 'repository_commit' to be a str")
        pulumi.set(__self__, "repository_commit", repository_commit)
        if repository_connector and not isinstance(repository_connector, str):
            raise TypeError("Expected argument 'repository_connector' to be a str")
        pulumi.set(__self__, "repository_connector", repository_connector)
        if repository_path and not isinstance(repository_path, str):
            raise TypeError("Expected argument 'repository_path' to be a str")
        pulumi.set(__self__, "repository_path", repository_path)
        if repository_url and not isinstance(repository_url, str):
            raise TypeError("Expected argument 'repository_url' to be a str")
        pulumi.set(__self__, "repository_url", repository_url)
        if synced and not isinstance(synced, int):
            raise TypeError("Expected argument 'synced' to be a int")
        pulumi.set(__self__, "synced", synced)
        if system and not isinstance(system, str):
            raise TypeError("Expected argument 'system' to be a str")
        pulumi.set(__self__, "system", system)
        if tags and not isinstance(tags, str):
            raise TypeError("Expected argument 'tags' to be a str")
        pulumi.set(__self__, "tags", tags)
        if testing_enabled and not isinstance(testing_enabled, bool):
            raise TypeError("Expected argument 'testing_enabled' to be a bool")
        pulumi.set(__self__, "testing_enabled", testing_enabled)
        if testing_metadata and not isinstance(testing_metadata, dict):
            raise TypeError("Expected argument 'testing_metadata' to be a dict")
        pulumi.set(__self__, "testing_metadata", testing_metadata)
        if updated and not isinstance(updated, int):
            raise TypeError("Expected argument 'updated' to be a int")
        pulumi.set(__self__, "updated", updated)
        if versions and not isinstance(versions, list):
            raise TypeError("Expected argument 'versions' to be a list")
        pulumi.set(__self__, "versions", versions)

    @_builtins.property
    @pulumi.getter
    def account(self) -> _builtins.str:
        """
        Account that owns the module
        """
        return pulumi.get(self, "account")

    @_builtins.property
    @pulumi.getter
    def created(self) -> _builtins.int:
        """
        Timestamp when the module was created
        """
        return pulumi.get(self, "created")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        Description of the module
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="gitTagStyle")
    def git_tag_style(self) -> _builtins.str:
        """
        Git Tag Style
        """
        return pulumi.get(self, "git_tag_style")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="moduleError")
    def module_error(self) -> _builtins.str:
        """
        Error while retrieving the module
        """
        return pulumi.get(self, "module_error")

    @_builtins.property
    @pulumi.getter(name="moduleId")
    def module_id(self) -> _builtins.str:
        """
        Identifier of the module to enable testing for
        """
        return pulumi.get(self, "module_id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        Name of the module
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def org(self) -> _builtins.str:
        """
        Organization identifier
        """
        return pulumi.get(self, "org")

    @_builtins.property
    @pulumi.getter
    def pipelines(self) -> Sequence[_builtins.str]:
        """
        List of pipeline IDs to create webhooks for triggering test executions
        """
        return pulumi.get(self, "pipelines")

    @_builtins.property
    @pulumi.getter
    def project(self) -> _builtins.str:
        """
        Project identifier
        """
        return pulumi.get(self, "project")

    @_builtins.property
    @pulumi.getter(name="providerConnector")
    def provider_connector(self) -> _builtins.str:
        """
        Provider connector for testing purposes
        """
        return pulumi.get(self, "provider_connector")

    @_builtins.property
    @pulumi.getter(name="provisionerType")
    def provisioner_type(self) -> _builtins.str:
        return pulumi.get(self, "provisioner_type")

    @_builtins.property
    @pulumi.getter(name="provisionerVersion")
    def provisioner_version(self) -> _builtins.str:
        """
        Provisioner version for testing purposes
        """
        return pulumi.get(self, "provisioner_version")

    @_builtins.property
    @pulumi.getter(name="releasePipeline")
    def release_pipeline(self) -> Optional[_builtins.str]:
        """
        Pipeline ID to create webhooks for releases
        """
        return pulumi.get(self, "release_pipeline")

    @_builtins.property
    @pulumi.getter
    def repository(self) -> _builtins.str:
        """
        For account connectors, the repository where the module is stored
        """
        return pulumi.get(self, "repository")

    @_builtins.property
    @pulumi.getter(name="repositoryBranch")
    def repository_branch(self) -> _builtins.str:
        """
        Repository Branch in which the module should be accessed
        """
        return pulumi.get(self, "repository_branch")

    @_builtins.property
    @pulumi.getter(name="repositoryCommit")
    def repository_commit(self) -> _builtins.str:
        """
        Repository Commit in which the module should be accessed
        """
        return pulumi.get(self, "repository_commit")

    @_builtins.property
    @pulumi.getter(name="repositoryConnector")
    def repository_connector(self) -> _builtins.str:
        """
        Repository Connector is the reference to the connector for the repository
        """
        return pulumi.get(self, "repository_connector")

    @_builtins.property
    @pulumi.getter(name="repositoryPath")
    def repository_path(self) -> _builtins.str:
        """
        Repository Path is the path in which the module resides
        """
        return pulumi.get(self, "repository_path")

    @_builtins.property
    @pulumi.getter(name="repositoryUrl")
    def repository_url(self) -> _builtins.str:
        """
        URL where the module is stored
        """
        return pulumi.get(self, "repository_url")

    @_builtins.property
    @pulumi.getter
    def synced(self) -> _builtins.int:
        """
        Timestamp when the module was last synced
        """
        return pulumi.get(self, "synced")

    @_builtins.property
    @pulumi.getter
    def system(self) -> _builtins.str:
        """
        Provider of the module
        """
        return pulumi.get(self, "system")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> _builtins.str:
        """
        Tags associated with the module
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="testingEnabled")
    def testing_enabled(self) -> _builtins.bool:
        """
        Whether testing is enabled for the module
        """
        return pulumi.get(self, "testing_enabled")

    @_builtins.property
    @pulumi.getter(name="testingMetadata")
    def testing_metadata(self) -> 'outputs.GetInfraModuleTestingTestingMetadataResult':
        """
        Testing metadata for the module
        """
        return pulumi.get(self, "testing_metadata")

    @_builtins.property
    @pulumi.getter
    def updated(self) -> _builtins.int:
        """
        Timestamp when the module was last modified
        """
        return pulumi.get(self, "updated")

    @_builtins.property
    @pulumi.getter
    def versions(self) -> Sequence[_builtins.str]:
        """
        Versions of the module
        """
        return pulumi.get(self, "versions")


class AwaitableGetInfraModuleTestingResult(GetInfraModuleTestingResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetInfraModuleTestingResult(
            account=self.account,
            created=self.created,
            description=self.description,
            git_tag_style=self.git_tag_style,
            id=self.id,
            module_error=self.module_error,
            module_id=self.module_id,
            name=self.name,
            org=self.org,
            pipelines=self.pipelines,
            project=self.project,
            provider_connector=self.provider_connector,
            provisioner_type=self.provisioner_type,
            provisioner_version=self.provisioner_version,
            release_pipeline=self.release_pipeline,
            repository=self.repository,
            repository_branch=self.repository_branch,
            repository_commit=self.repository_commit,
            repository_connector=self.repository_connector,
            repository_path=self.repository_path,
            repository_url=self.repository_url,
            synced=self.synced,
            system=self.system,
            tags=self.tags,
            testing_enabled=self.testing_enabled,
            testing_metadata=self.testing_metadata,
            updated=self.updated,
            versions=self.versions)


def get_infra_module_testing(module_id: Optional[_builtins.str] = None,
                             org: Optional[_builtins.str] = None,
                             pipelines: Optional[Sequence[_builtins.str]] = None,
                             project: Optional[_builtins.str] = None,
                             provider_connector: Optional[_builtins.str] = None,
                             provisioner_type: Optional[_builtins.str] = None,
                             provisioner_version: Optional[_builtins.str] = None,
                             release_pipeline: Optional[_builtins.str] = None,
                             testing_enabled: Optional[_builtins.bool] = None,
                             testing_metadata: Optional[Union['GetInfraModuleTestingTestingMetadataArgs', 'GetInfraModuleTestingTestingMetadataArgsDict']] = None,
                             updated: Optional[_builtins.int] = None,
                             versions: Optional[Sequence[_builtins.str]] = None,
                             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetInfraModuleTestingResult:
    """
    Data source for retrieving modules testing metadata from the module registry.


    :param _builtins.str module_id: Identifier of the module to enable testing for
    :param _builtins.str org: Organization identifier
    :param Sequence[_builtins.str] pipelines: List of pipeline IDs to create webhooks for triggering test executions
    :param _builtins.str project: Project identifier
    :param _builtins.str provider_connector: Provider connector for testing purposes
    :param _builtins.str provisioner_version: Provisioner version for testing purposes
    :param _builtins.str release_pipeline: Pipeline ID to create webhooks for releases
    :param _builtins.bool testing_enabled: Whether testing is enabled for the module
    :param Union['GetInfraModuleTestingTestingMetadataArgs', 'GetInfraModuleTestingTestingMetadataArgsDict'] testing_metadata: Testing metadata for the module
    :param _builtins.int updated: Timestamp when the module was last modified
    :param Sequence[_builtins.str] versions: Versions of the module
    """
    __args__ = dict()
    __args__['moduleId'] = module_id
    __args__['org'] = org
    __args__['pipelines'] = pipelines
    __args__['project'] = project
    __args__['providerConnector'] = provider_connector
    __args__['provisionerType'] = provisioner_type
    __args__['provisionerVersion'] = provisioner_version
    __args__['releasePipeline'] = release_pipeline
    __args__['testingEnabled'] = testing_enabled
    __args__['testingMetadata'] = testing_metadata
    __args__['updated'] = updated
    __args__['versions'] = versions
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getInfraModuleTesting:getInfraModuleTesting', __args__, opts=opts, typ=GetInfraModuleTestingResult).value

    return AwaitableGetInfraModuleTestingResult(
        account=pulumi.get(__ret__, 'account'),
        created=pulumi.get(__ret__, 'created'),
        description=pulumi.get(__ret__, 'description'),
        git_tag_style=pulumi.get(__ret__, 'git_tag_style'),
        id=pulumi.get(__ret__, 'id'),
        module_error=pulumi.get(__ret__, 'module_error'),
        module_id=pulumi.get(__ret__, 'module_id'),
        name=pulumi.get(__ret__, 'name'),
        org=pulumi.get(__ret__, 'org'),
        pipelines=pulumi.get(__ret__, 'pipelines'),
        project=pulumi.get(__ret__, 'project'),
        provider_connector=pulumi.get(__ret__, 'provider_connector'),
        provisioner_type=pulumi.get(__ret__, 'provisioner_type'),
        provisioner_version=pulumi.get(__ret__, 'provisioner_version'),
        release_pipeline=pulumi.get(__ret__, 'release_pipeline'),
        repository=pulumi.get(__ret__, 'repository'),
        repository_branch=pulumi.get(__ret__, 'repository_branch'),
        repository_commit=pulumi.get(__ret__, 'repository_commit'),
        repository_connector=pulumi.get(__ret__, 'repository_connector'),
        repository_path=pulumi.get(__ret__, 'repository_path'),
        repository_url=pulumi.get(__ret__, 'repository_url'),
        synced=pulumi.get(__ret__, 'synced'),
        system=pulumi.get(__ret__, 'system'),
        tags=pulumi.get(__ret__, 'tags'),
        testing_enabled=pulumi.get(__ret__, 'testing_enabled'),
        testing_metadata=pulumi.get(__ret__, 'testing_metadata'),
        updated=pulumi.get(__ret__, 'updated'),
        versions=pulumi.get(__ret__, 'versions'))
def get_infra_module_testing_output(module_id: Optional[pulumi.Input[_builtins.str]] = None,
                                    org: Optional[pulumi.Input[_builtins.str]] = None,
                                    pipelines: Optional[pulumi.Input[Sequence[_builtins.str]]] = None,
                                    project: Optional[pulumi.Input[_builtins.str]] = None,
                                    provider_connector: Optional[pulumi.Input[_builtins.str]] = None,
                                    provisioner_type: Optional[pulumi.Input[_builtins.str]] = None,
                                    provisioner_version: Optional[pulumi.Input[_builtins.str]] = None,
                                    release_pipeline: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                    testing_enabled: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                                    testing_metadata: Optional[pulumi.Input[Optional[Union['GetInfraModuleTestingTestingMetadataArgs', 'GetInfraModuleTestingTestingMetadataArgsDict']]]] = None,
                                    updated: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                                    versions: Optional[pulumi.Input[Optional[Sequence[_builtins.str]]]] = None,
                                    opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetInfraModuleTestingResult]:
    """
    Data source for retrieving modules testing metadata from the module registry.


    :param _builtins.str module_id: Identifier of the module to enable testing for
    :param _builtins.str org: Organization identifier
    :param Sequence[_builtins.str] pipelines: List of pipeline IDs to create webhooks for triggering test executions
    :param _builtins.str project: Project identifier
    :param _builtins.str provider_connector: Provider connector for testing purposes
    :param _builtins.str provisioner_version: Provisioner version for testing purposes
    :param _builtins.str release_pipeline: Pipeline ID to create webhooks for releases
    :param _builtins.bool testing_enabled: Whether testing is enabled for the module
    :param Union['GetInfraModuleTestingTestingMetadataArgs', 'GetInfraModuleTestingTestingMetadataArgsDict'] testing_metadata: Testing metadata for the module
    :param _builtins.int updated: Timestamp when the module was last modified
    :param Sequence[_builtins.str] versions: Versions of the module
    """
    __args__ = dict()
    __args__['moduleId'] = module_id
    __args__['org'] = org
    __args__['pipelines'] = pipelines
    __args__['project'] = project
    __args__['providerConnector'] = provider_connector
    __args__['provisionerType'] = provisioner_type
    __args__['provisionerVersion'] = provisioner_version
    __args__['releasePipeline'] = release_pipeline
    __args__['testingEnabled'] = testing_enabled
    __args__['testingMetadata'] = testing_metadata
    __args__['updated'] = updated
    __args__['versions'] = versions
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getInfraModuleTesting:getInfraModuleTesting', __args__, opts=opts, typ=GetInfraModuleTestingResult)
    return __ret__.apply(lambda __response__: GetInfraModuleTestingResult(
        account=pulumi.get(__response__, 'account'),
        created=pulumi.get(__response__, 'created'),
        description=pulumi.get(__response__, 'description'),
        git_tag_style=pulumi.get(__response__, 'git_tag_style'),
        id=pulumi.get(__response__, 'id'),
        module_error=pulumi.get(__response__, 'module_error'),
        module_id=pulumi.get(__response__, 'module_id'),
        name=pulumi.get(__response__, 'name'),
        org=pulumi.get(__response__, 'org'),
        pipelines=pulumi.get(__response__, 'pipelines'),
        project=pulumi.get(__response__, 'project'),
        provider_connector=pulumi.get(__response__, 'provider_connector'),
        provisioner_type=pulumi.get(__response__, 'provisioner_type'),
        provisioner_version=pulumi.get(__response__, 'provisioner_version'),
        release_pipeline=pulumi.get(__response__, 'release_pipeline'),
        repository=pulumi.get(__response__, 'repository'),
        repository_branch=pulumi.get(__response__, 'repository_branch'),
        repository_commit=pulumi.get(__response__, 'repository_commit'),
        repository_connector=pulumi.get(__response__, 'repository_connector'),
        repository_path=pulumi.get(__response__, 'repository_path'),
        repository_url=pulumi.get(__response__, 'repository_url'),
        synced=pulumi.get(__response__, 'synced'),
        system=pulumi.get(__response__, 'system'),
        tags=pulumi.get(__response__, 'tags'),
        testing_enabled=pulumi.get(__response__, 'testing_enabled'),
        testing_metadata=pulumi.get(__response__, 'testing_metadata'),
        updated=pulumi.get(__response__, 'updated'),
        versions=pulumi.get(__response__, 'versions')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['IpAllowlistArgs', 'IpAllowlist']

@pulumi.input_type
class IpAllowlistArgs:
    def __init__(__self__, *,
                 identifier: pulumi.Input[_builtins.str],
                 ip_address: pulumi.Input[_builtins.str],
                 allowed_source_types: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a IpAllowlist resource.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] ip_address: CIDR range or IP address to allow.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_source_types: List of sources to allow. Valid values are `UI` and `API`.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.bool] enabled: Whether the allowlist config is enabled.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        """
        pulumi.set(__self__, "identifier", identifier)
        pulumi.set(__self__, "ip_address", ip_address)
        if allowed_source_types is not None:
            pulumi.set(__self__, "allowed_source_types", allowed_source_types)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Input[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="ipAddress")
    def ip_address(self) -> pulumi.Input[_builtins.str]:
        """
        CIDR range or IP address to allow.
        """
        return pulumi.get(self, "ip_address")

    @ip_address.setter
    def ip_address(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "ip_address", value)

    @_builtins.property
    @pulumi.getter(name="allowedSourceTypes")
    def allowed_source_types(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of sources to allow. Valid values are `UI` and `API`.
        """
        return pulumi.get(self, "allowed_source_types")

    @allowed_source_types.setter
    def allowed_source_types(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "allowed_source_types", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the allowlist config is enabled.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _IpAllowlistState:
    def __init__(__self__, *,
                 allowed_source_types: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 created: Optional[pulumi.Input[_builtins.int]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 ip_address: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 updated: Optional[pulumi.Input[_builtins.int]] = None):
        """
        Input properties used for looking up and filtering IpAllowlist resources.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_source_types: List of sources to allow. Valid values are `UI` and `API`.
        :param pulumi.Input[_builtins.int] created: Creation timestamp for the config.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.bool] enabled: Whether the allowlist config is enabled.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] ip_address: CIDR range or IP address to allow.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input[_builtins.int] updated: Last update timestamp for the config.
        """
        if allowed_source_types is not None:
            pulumi.set(__self__, "allowed_source_types", allowed_source_types)
        if created is not None:
            pulumi.set(__self__, "created", created)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if ip_address is not None:
            pulumi.set(__self__, "ip_address", ip_address)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if updated is not None:
            pulumi.set(__self__, "updated", updated)

    @_builtins.property
    @pulumi.getter(name="allowedSourceTypes")
    def allowed_source_types(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of sources to allow. Valid values are `UI` and `API`.
        """
        return pulumi.get(self, "allowed_source_types")

    @allowed_source_types.setter
    def allowed_source_types(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "allowed_source_types", value)

    @_builtins.property
    @pulumi.getter
    def created(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Creation timestamp for the config.
        """
        return pulumi.get(self, "created")

    @created.setter
    def created(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "created", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the allowlist config is enabled.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="ipAddress")
    def ip_address(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        CIDR range or IP address to allow.
        """
        return pulumi.get(self, "ip_address")

    @ip_address.setter
    def ip_address(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ip_address", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter
    def updated(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Last update timestamp for the config.
        """
        return pulumi.get(self, "updated")

    @updated.setter
    def updated(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "updated", value)


@pulumi.type_token("harness:platform/ipAllowlist:IpAllowlist")
class IpAllowlist(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allowed_source_types: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 ip_address: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        """
        Resource for managing IP allowlist configs.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        example = harness.platform.IpAllowlist("example",
            identifier="identifier",
            name="name",
            ip_address="0.0.0.0/0",
            allowed_source_types=["API"],
            enabled=True,
            description="allowlist example",
            tags=["foo:bar"])
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_source_types: List of sources to allow. Valid values are `UI` and `API`.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.bool] enabled: Whether the allowlist config is enabled.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] ip_address: CIDR range or IP address to allow.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: IpAllowlistArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for managing IP allowlist configs.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        example = harness.platform.IpAllowlist("example",
            identifier="identifier",
            name="name",
            ip_address="0.0.0.0/0",
            allowed_source_types=["API"],
            enabled=True,
            description="allowlist example",
            tags=["foo:bar"])
        ```

        :param str resource_name: The name of the resource.
        :param IpAllowlistArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(IpAllowlistArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allowed_source_types: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 ip_address: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = IpAllowlistArgs.__new__(IpAllowlistArgs)

            __props__.__dict__["allowed_source_types"] = allowed_source_types
            __props__.__dict__["description"] = description
            __props__.__dict__["enabled"] = enabled
            if identifier is None and not opts.urn:
                raise TypeError("Missing required property 'identifier'")
            __props__.__dict__["identifier"] = identifier
            if ip_address is None and not opts.urn:
                raise TypeError("Missing required property 'ip_address'")
            __props__.__dict__["ip_address"] = ip_address
            __props__.__dict__["name"] = name
            __props__.__dict__["tags"] = tags
            __props__.__dict__["created"] = None
            __props__.__dict__["updated"] = None
        super(IpAllowlist, __self__).__init__(
            'harness:platform/ipAllowlist:IpAllowlist',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            allowed_source_types: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            created: Optional[pulumi.Input[_builtins.int]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            identifier: Optional[pulumi.Input[_builtins.str]] = None,
            ip_address: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            updated: Optional[pulumi.Input[_builtins.int]] = None) -> 'IpAllowlist':
        """
        Get an existing IpAllowlist resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_source_types: List of sources to allow. Valid values are `UI` and `API`.
        :param pulumi.Input[_builtins.int] created: Creation timestamp for the config.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.bool] enabled: Whether the allowlist config is enabled.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] ip_address: CIDR range or IP address to allow.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input[_builtins.int] updated: Last update timestamp for the config.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _IpAllowlistState.__new__(_IpAllowlistState)

        __props__.__dict__["allowed_source_types"] = allowed_source_types
        __props__.__dict__["created"] = created
        __props__.__dict__["description"] = description
        __props__.__dict__["enabled"] = enabled
        __props__.__dict__["identifier"] = identifier
        __props__.__dict__["ip_address"] = ip_address
        __props__.__dict__["name"] = name
        __props__.__dict__["tags"] = tags
        __props__.__dict__["updated"] = updated
        return IpAllowlist(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="allowedSourceTypes")
    def allowed_source_types(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        List of sources to allow. Valid values are `UI` and `API`.
        """
        return pulumi.get(self, "allowed_source_types")

    @_builtins.property
    @pulumi.getter
    def created(self) -> pulumi.Output[_builtins.int]:
        """
        Creation timestamp for the config.
        """
        return pulumi.get(self, "created")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Whether the allowlist config is enabled.
        """
        return pulumi.get(self, "enabled")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Output[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter(name="ipAddress")
    def ip_address(self) -> pulumi.Output[_builtins.str]:
        """
        CIDR range or IP address to allow.
        """
        return pulumi.get(self, "ip_address")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter
    def updated(self) -> pulumi.Output[_builtins.int]:
        """
        Last update timestamp for the config.
        """
        return pulumi.get(self, "updated")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetDelegateResult',
    'AwaitableGetDelegateResult',
    'get_delegate',
    'get_delegate_output',
]

@pulumi.output_type
class GetDelegateResult:
    """
    A collection of values returned by getDelegate.
    """
    def __init__(__self__, account_id=None, description=None, hostname=None, id=None, ip=None, last_heartbeat=None, name=None, polling_mode_enabled=None, profile_id=None, status=None, type=None, version=None):
        if account_id and not isinstance(account_id, str):
            raise TypeError("Expected argument 'account_id' to be a str")
        pulumi.set(__self__, "account_id", account_id)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if hostname and not isinstance(hostname, str):
            raise TypeError("Expected argument 'hostname' to be a str")
        pulumi.set(__self__, "hostname", hostname)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ip and not isinstance(ip, str):
            raise TypeError("Expected argument 'ip' to be a str")
        pulumi.set(__self__, "ip", ip)
        if last_heartbeat and not isinstance(last_heartbeat, str):
            raise TypeError("Expected argument 'last_heartbeat' to be a str")
        pulumi.set(__self__, "last_heartbeat", last_heartbeat)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if polling_mode_enabled and not isinstance(polling_mode_enabled, bool):
            raise TypeError("Expected argument 'polling_mode_enabled' to be a bool")
        pulumi.set(__self__, "polling_mode_enabled", polling_mode_enabled)
        if profile_id and not isinstance(profile_id, str):
            raise TypeError("Expected argument 'profile_id' to be a str")
        pulumi.set(__self__, "profile_id", profile_id)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)
        if version and not isinstance(version, str):
            raise TypeError("Expected argument 'version' to be a str")
        pulumi.set(__self__, "version", version)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> _builtins.str:
        """
        The account id the delegate belongs to.
        """
        return pulumi.get(self, "account_id")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        The description of the delegate.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def hostname(self) -> Optional[_builtins.str]:
        """
        The hostname of the delegate.
        """
        return pulumi.get(self, "hostname")

    @_builtins.property
    @pulumi.getter
    def id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the delegate
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def ip(self) -> _builtins.str:
        """
        The ip address of the delegate.
        """
        return pulumi.get(self, "ip")

    @_builtins.property
    @pulumi.getter(name="lastHeartbeat")
    def last_heartbeat(self) -> _builtins.str:
        """
        The last time the delegate was heard from.
        """
        return pulumi.get(self, "last_heartbeat")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        The name of the delegate to query for.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="pollingModeEnabled")
    def polling_mode_enabled(self) -> _builtins.bool:
        """
        Whether the delegate is in polling mode.
        """
        return pulumi.get(self, "polling_mode_enabled")

    @_builtins.property
    @pulumi.getter(name="profileId")
    def profile_id(self) -> _builtins.str:
        """
        The id of the profile assigned to the delegate.
        """
        return pulumi.get(self, "profile_id")

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[_builtins.str]:
        """
        The status of the delegate to query for. Valid values are DELETED, ENABLED, WAITING*FOR*APPROVAL
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[_builtins.str]:
        """
        The type of the delegate to query for. Valid values are DOCKER, ECS, HELM*DELEGATE, KUBERNETES, SHELL*SCRIPT
        """
        return pulumi.get(self, "type")

    @_builtins.property
    @pulumi.getter
    def version(self) -> _builtins.str:
        """
        The version of the delegate.
        """
        return pulumi.get(self, "version")


class AwaitableGetDelegateResult(GetDelegateResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDelegateResult(
            account_id=self.account_id,
            description=self.description,
            hostname=self.hostname,
            id=self.id,
            ip=self.ip,
            last_heartbeat=self.last_heartbeat,
            name=self.name,
            polling_mode_enabled=self.polling_mode_enabled,
            profile_id=self.profile_id,
            status=self.status,
            type=self.type,
            version=self.version)


def get_delegate(hostname: Optional[_builtins.str] = None,
                 id: Optional[_builtins.str] = None,
                 name: Optional[_builtins.str] = None,
                 status: Optional[_builtins.str] = None,
                 type: Optional[_builtins.str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDelegateResult:
    """
    Data source for retrieving a Harness delegate. If more than one delegate matches the query the first one will be returned.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    example = harness.get_delegate(name="harness-delegate",
        type="KUBERNETES",
        status="ENABLED")
    ```


    :param _builtins.str hostname: The hostname of the delegate.
    :param _builtins.str id: Unique identifier of the delegate
    :param _builtins.str name: The name of the delegate to query for.
    :param _builtins.str status: The status of the delegate to query for. Valid values are DELETED, ENABLED, WAITING*FOR*APPROVAL
    :param _builtins.str type: The type of the delegate to query for. Valid values are DOCKER, ECS, HELM*DELEGATE, KUBERNETES, SHELL*SCRIPT
    """
    __args__ = dict()
    __args__['hostname'] = hostname
    __args__['id'] = id
    __args__['name'] = name
    __args__['status'] = status
    __args__['type'] = type
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:index/getDelegate:getDelegate', __args__, opts=opts, typ=GetDelegateResult).value

    return AwaitableGetDelegateResult(
        account_id=pulumi.get(__ret__, 'account_id'),
        description=pulumi.get(__ret__, 'description'),
        hostname=pulumi.get(__ret__, 'hostname'),
        id=pulumi.get(__ret__, 'id'),
        ip=pulumi.get(__ret__, 'ip'),
        last_heartbeat=pulumi.get(__ret__, 'last_heartbeat'),
        name=pulumi.get(__ret__, 'name'),
        polling_mode_enabled=pulumi.get(__ret__, 'polling_mode_enabled'),
        profile_id=pulumi.get(__ret__, 'profile_id'),
        status=pulumi.get(__ret__, 'status'),
        type=pulumi.get(__ret__, 'type'),
        version=pulumi.get(__ret__, 'version'))
def get_delegate_output(hostname: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                        id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                        name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                        status: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                        type: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDelegateResult]:
    """
    Data source for retrieving a Harness delegate. If more than one delegate matches the query the first one will be returned.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    example = harness.get_delegate(name="harness-delegate",
        type="KUBERNETES",
        status="ENABLED")
    ```


    :param _builtins.str hostname: The hostname of the delegate.
    :param _builtins.str id: Unique identifier of the delegate
    :param _builtins.str name: The name of the delegate to query for.
    :param _builtins.str status: The status of the delegate to query for. Valid values are DELETED, ENABLED, WAITING*FOR*APPROVAL
    :param _builtins.str type: The type of the delegate to query for. Valid values are DOCKER, ECS, HELM*DELEGATE, KUBERNETES, SHELL*SCRIPT
    """
    __args__ = dict()
    __args__['hostname'] = hostname
    __args__['id'] = id
    __args__['name'] = name
    __args__['status'] = status
    __args__['type'] = type
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:index/getDelegate:getDelegate', __args__, opts=opts, typ=GetDelegateResult)
    return __ret__.apply(lambda __response__: GetDelegateResult(
        account_id=pulumi.get(__response__, 'account_id'),
        description=pulumi.get(__response__, 'description'),
        hostname=pulumi.get(__response__, 'hostname'),
        id=pulumi.get(__response__, 'id'),
        ip=pulumi.get(__response__, 'ip'),
        last_heartbeat=pulumi.get(__response__, 'last_heartbeat'),
        name=pulumi.get(__response__, 'name'),
        polling_mode_enabled=pulumi.get(__response__, 'polling_mode_enabled'),
        profile_id=pulumi.get(__response__, 'profile_id'),
        status=pulumi.get(__response__, 'status'),
        type=pulumi.get(__response__, 'type'),
        version=pulumi.get(__response__, 'version')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
from .. import _utilities
import typing
# Export this package's modules as members:
from .aws_alb import *
from .aws_proxy import *
from .azure_gateway import *
from .azure_proxy import *
from .gcp_proxy import *
from .get_aws_alb import *
from .get_aws_proxy import *
from .get_azure_gateway import *
from .get_azure_proxy import *
from .get_gcp_proxy import *
from .get_rule_ecs import *
from .get_rule_rds import *
from .get_rule_scale_group import *
from .get_rule_vm import *
from .get_schedule import *
from .rule_ecs import *
from .rule_rds import *
from .rule_scale_group import *
from .rule_vm import *
from .schedule import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetUsergroupResult',
    'AwaitableGetUsergroupResult',
    'get_usergroup',
    'get_usergroup_output',
]

@pulumi.output_type
class GetUsergroupResult:
    """
    A collection of values returned by getUsergroup.
    """
    def __init__(__self__, description=None, externally_managed=None, id=None, identifier=None, linked_sso_display_name=None, linked_sso_id=None, linked_sso_type=None, name=None, notification_configs=None, org_id=None, project_id=None, sso_group_id=None, sso_group_name=None, sso_linked=None, tags=None, users=None):
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if externally_managed and not isinstance(externally_managed, bool):
            raise TypeError("Expected argument 'externally_managed' to be a bool")
        pulumi.set(__self__, "externally_managed", externally_managed)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identifier and not isinstance(identifier, str):
            raise TypeError("Expected argument 'identifier' to be a str")
        pulumi.set(__self__, "identifier", identifier)
        if linked_sso_display_name and not isinstance(linked_sso_display_name, str):
            raise TypeError("Expected argument 'linked_sso_display_name' to be a str")
        pulumi.set(__self__, "linked_sso_display_name", linked_sso_display_name)
        if linked_sso_id and not isinstance(linked_sso_id, str):
            raise TypeError("Expected argument 'linked_sso_id' to be a str")
        pulumi.set(__self__, "linked_sso_id", linked_sso_id)
        if linked_sso_type and not isinstance(linked_sso_type, str):
            raise TypeError("Expected argument 'linked_sso_type' to be a str")
        pulumi.set(__self__, "linked_sso_type", linked_sso_type)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if notification_configs and not isinstance(notification_configs, list):
            raise TypeError("Expected argument 'notification_configs' to be a list")
        pulumi.set(__self__, "notification_configs", notification_configs)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if sso_group_id and not isinstance(sso_group_id, str):
            raise TypeError("Expected argument 'sso_group_id' to be a str")
        pulumi.set(__self__, "sso_group_id", sso_group_id)
        if sso_group_name and not isinstance(sso_group_name, str):
            raise TypeError("Expected argument 'sso_group_name' to be a str")
        pulumi.set(__self__, "sso_group_name", sso_group_name)
        if sso_linked and not isinstance(sso_linked, bool):
            raise TypeError("Expected argument 'sso_linked' to be a bool")
        pulumi.set(__self__, "sso_linked", sso_linked)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if users and not isinstance(users, list):
            raise TypeError("Expected argument 'users' to be a list")
        pulumi.set(__self__, "users", users)

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="externallyManaged")
    def externally_managed(self) -> _builtins.bool:
        """
        Whether the user group is externally managed.
        """
        return pulumi.get(self, "externally_managed")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter(name="linkedSsoDisplayName")
    def linked_sso_display_name(self) -> _builtins.str:
        """
        Name of the linked SSO.
        """
        return pulumi.get(self, "linked_sso_display_name")

    @_builtins.property
    @pulumi.getter(name="linkedSsoId")
    def linked_sso_id(self) -> _builtins.str:
        """
        The SSO account ID that the user group is linked to.
        """
        return pulumi.get(self, "linked_sso_id")

    @_builtins.property
    @pulumi.getter(name="linkedSsoType")
    def linked_sso_type(self) -> _builtins.str:
        """
        Type of linked SSO.
        """
        return pulumi.get(self, "linked_sso_type")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="notificationConfigs")
    def notification_configs(self) -> Optional[Sequence['outputs.GetUsergroupNotificationConfigResult']]:
        """
        List of notification settings.
        """
        return pulumi.get(self, "notification_configs")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="ssoGroupId")
    def sso_group_id(self) -> _builtins.str:
        """
        Identifier of the userGroup in SSO.
        """
        return pulumi.get(self, "sso_group_id")

    @_builtins.property
    @pulumi.getter(name="ssoGroupName")
    def sso_group_name(self) -> _builtins.str:
        """
        Name of the SSO userGroup.
        """
        return pulumi.get(self, "sso_group_name")

    @_builtins.property
    @pulumi.getter(name="ssoLinked")
    def sso_linked(self) -> _builtins.bool:
        """
        Whether sso is linked or not.
        """
        return pulumi.get(self, "sso_linked")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Sequence[_builtins.str]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter
    def users(self) -> Sequence[_builtins.str]:
        """
        List of users in the UserGroup.
        """
        return pulumi.get(self, "users")


class AwaitableGetUsergroupResult(GetUsergroupResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetUsergroupResult(
            description=self.description,
            externally_managed=self.externally_managed,
            id=self.id,
            identifier=self.identifier,
            linked_sso_display_name=self.linked_sso_display_name,
            linked_sso_id=self.linked_sso_id,
            linked_sso_type=self.linked_sso_type,
            name=self.name,
            notification_configs=self.notification_configs,
            org_id=self.org_id,
            project_id=self.project_id,
            sso_group_id=self.sso_group_id,
            sso_group_name=self.sso_group_name,
            sso_linked=self.sso_linked,
            tags=self.tags,
            users=self.users)


def get_usergroup(identifier: Optional[_builtins.str] = None,
                  name: Optional[_builtins.str] = None,
                  notification_configs: Optional[Sequence[Union['GetUsergroupNotificationConfigArgs', 'GetUsergroupNotificationConfigArgsDict']]] = None,
                  org_id: Optional[_builtins.str] = None,
                  project_id: Optional[_builtins.str] = None,
                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetUsergroupResult:
    """
    Data source for retrieving a Harness User Group.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    example_by_id = harness.platform.get_usergroup(identifier="identifier",
        org_id="org_id",
        project_id="project_id")
    example_by_name = harness.platform.get_usergroup(name="name",
        org_id="org_id",
        project_id="project_id")
    ```


    :param _builtins.str identifier: Unique identifier of the resource.
    :param _builtins.str name: Name of the resource.
    :param Sequence[Union['GetUsergroupNotificationConfigArgs', 'GetUsergroupNotificationConfigArgsDict']] notification_configs: List of notification settings.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str project_id: Unique identifier of the project.
    """
    __args__ = dict()
    __args__['identifier'] = identifier
    __args__['name'] = name
    __args__['notificationConfigs'] = notification_configs
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getUsergroup:getUsergroup', __args__, opts=opts, typ=GetUsergroupResult).value

    return AwaitableGetUsergroupResult(
        description=pulumi.get(__ret__, 'description'),
        externally_managed=pulumi.get(__ret__, 'externally_managed'),
        id=pulumi.get(__ret__, 'id'),
        identifier=pulumi.get(__ret__, 'identifier'),
        linked_sso_display_name=pulumi.get(__ret__, 'linked_sso_display_name'),
        linked_sso_id=pulumi.get(__ret__, 'linked_sso_id'),
        linked_sso_type=pulumi.get(__ret__, 'linked_sso_type'),
        name=pulumi.get(__ret__, 'name'),
        notification_configs=pulumi.get(__ret__, 'notification_configs'),
        org_id=pulumi.get(__ret__, 'org_id'),
        project_id=pulumi.get(__ret__, 'project_id'),
        sso_group_id=pulumi.get(__ret__, 'sso_group_id'),
        sso_group_name=pulumi.get(__ret__, 'sso_group_name'),
        sso_linked=pulumi.get(__ret__, 'sso_linked'),
        tags=pulumi.get(__ret__, 'tags'),
        users=pulumi.get(__ret__, 'users'))
def get_usergroup_output(identifier: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                         name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                         notification_configs: Optional[pulumi.Input[Optional[Sequence[Union['GetUsergroupNotificationConfigArgs', 'GetUsergroupNotificationConfigArgsDict']]]]] = None,
                         org_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                         project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                         opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetUsergroupResult]:
    """
    Data source for retrieving a Harness User Group.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    example_by_id = harness.platform.get_usergroup(identifier="identifier",
        org_id="org_id",
        project_id="project_id")
    example_by_name = harness.platform.get_usergroup(name="name",
        org_id="org_id",
        project_id="project_id")
    ```


    :param _builtins.str identifier: Unique identifier of the resource.
    :param _builtins.str name: Name of the resource.
    :param Sequence[Union['GetUsergroupNotificationConfigArgs', 'GetUsergroupNotificationConfigArgsDict']] notification_configs: List of notification settings.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str project_id: Unique identifier of the project.
    """
    __args__ = dict()
    __args__['identifier'] = identifier
    __args__['name'] = name
    __args__['notificationConfigs'] = notification_configs
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getUsergroup:getUsergroup', __args__, opts=opts, typ=GetUsergroupResult)
    return __ret__.apply(lambda __response__: GetUsergroupResult(
        description=pulumi.get(__response__, 'description'),
        externally_managed=pulumi.get(__response__, 'externally_managed'),
        id=pulumi.get(__response__, 'id'),
        identifier=pulumi.get(__response__, 'identifier'),
        linked_sso_display_name=pulumi.get(__response__, 'linked_sso_display_name'),
        linked_sso_id=pulumi.get(__response__, 'linked_sso_id'),
        linked_sso_type=pulumi.get(__response__, 'linked_sso_type'),
        name=pulumi.get(__response__, 'name'),
        notification_configs=pulumi.get(__response__, 'notification_configs'),
        org_id=pulumi.get(__response__, 'org_id'),
        project_id=pulumi.get(__response__, 'project_id'),
        sso_group_id=pulumi.get(__response__, 'sso_group_id'),
        sso_group_name=pulumi.get(__response__, 'sso_group_name'),
        sso_linked=pulumi.get(__response__, 'sso_linked'),
        tags=pulumi.get(__response__, 'tags'),
        users=pulumi.get(__response__, 'users')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

import types

__config__ = pulumi.Config('harness')


class _ExportableConfig(types.ModuleType):
    @_builtins.property
    def account_id(self) -> Optional[str]:
        """
        The Harness account id. This can also be set using the `HARNESS_ACCOUNT_ID` environment variable.
        """
        return __config__.get('accountId') or _utilities.get_env('HARNESS_ACCOUNT_ID')

    @_builtins.property
    def api_key(self) -> Optional[str]:
        """
        The Harness API key. This can also be set using the `HARNESS_API_KEY` environment variable. For more information to create an API key in FirstGen, see https://docs.harness.io/article/smloyragsm-api-keys#create_an_api_key.
        """
        return __config__.get('apiKey') or _utilities.get_env('HARNESS_API_KEY')

    @_builtins.property
    def endpoint(self) -> Optional[str]:
        """
        The URL of the Harness API endpoint. The default is `https://app.harness.io/gateway`. This can also be set using the `HARNESS_ENDPOINT` environment variable.
        """
        return __config__.get('endpoint') or _utilities.get_env('HARNESS_ENDPOINT')

    @_builtins.property
    def platform_api_key(self) -> Optional[str]:
        """
        The API key for the Harness next gen platform. This can also be set using the `HARNESS_PLATFORM_API_KEY` environment variable. For more information to create an API key in NextGen, see https://docs.harness.io/article/tdoad7xrh9-add-and-manage-api-keys.
        """
        return __config__.get('platformApiKey') or _utilities.get_env('HARNESS_PLATFORM_API_KEY')




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetGitopsAgentDeployYamlResult',
    'AwaitableGetGitopsAgentDeployYamlResult',
    'get_gitops_agent_deploy_yaml',
    'get_gitops_agent_deploy_yaml_output',
]

@pulumi.output_type
class GetGitopsAgentDeployYamlResult:
    """
    A collection of values returned by getGitopsAgentDeployYaml.
    """
    def __init__(__self__, account_id=None, argocd_settings=None, ca_data=None, id=None, identifier=None, namespace=None, org_id=None, private_key=None, project_id=None, proxies=None, skip_crds=None, yaml=None):
        if account_id and not isinstance(account_id, str):
            raise TypeError("Expected argument 'account_id' to be a str")
        pulumi.set(__self__, "account_id", account_id)
        if argocd_settings and not isinstance(argocd_settings, dict):
            raise TypeError("Expected argument 'argocd_settings' to be a dict")
        pulumi.set(__self__, "argocd_settings", argocd_settings)
        if ca_data and not isinstance(ca_data, str):
            raise TypeError("Expected argument 'ca_data' to be a str")
        pulumi.set(__self__, "ca_data", ca_data)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identifier and not isinstance(identifier, str):
            raise TypeError("Expected argument 'identifier' to be a str")
        pulumi.set(__self__, "identifier", identifier)
        if namespace and not isinstance(namespace, str):
            raise TypeError("Expected argument 'namespace' to be a str")
        pulumi.set(__self__, "namespace", namespace)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if private_key and not isinstance(private_key, str):
            raise TypeError("Expected argument 'private_key' to be a str")
        pulumi.set(__self__, "private_key", private_key)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if proxies and not isinstance(proxies, list):
            raise TypeError("Expected argument 'proxies' to be a list")
        pulumi.set(__self__, "proxies", proxies)
        if skip_crds and not isinstance(skip_crds, bool):
            raise TypeError("Expected argument 'skip_crds' to be a bool")
        pulumi.set(__self__, "skip_crds", skip_crds)
        if yaml and not isinstance(yaml, str):
            raise TypeError("Expected argument 'yaml' to be a str")
        pulumi.set(__self__, "yaml", yaml)

    @_builtins.property
    @pulumi.getter(name="accountId")
    @_utilities.deprecated("""This field is deprecated and will be removed in a future release.""")
    def account_id(self) -> _builtins.str:
        """
        Account identifier of the GitOps agent.
        """
        return pulumi.get(self, "account_id")

    @_builtins.property
    @pulumi.getter(name="argocdSettings")
    def argocd_settings(self) -> Optional['outputs.GetGitopsAgentDeployYamlArgocdSettingsResult']:
        """
        Argocd settings for the GitOps agent. Values set here will be overridden by the values set in the argocd settings in case of complete installation of agent + argocd. Each param contains as a description about what it will enable.
        """
        return pulumi.get(self, "argocd_settings")

    @_builtins.property
    @pulumi.getter(name="caData")
    def ca_data(self) -> Optional[_builtins.str]:
        """
        CA data of the GitOps agent, base64 encoded content of ca chain.
        """
        return pulumi.get(self, "ca_data")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> _builtins.str:
        """
        Identifier of the GitOps agent.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter
    def namespace(self) -> _builtins.str:
        """
        The kubernetes namespace where the agent is installed.
        """
        return pulumi.get(self, "namespace")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[_builtins.str]:
        """
        Organization identifier of the GitOps agent.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="privateKey")
    def private_key(self) -> Optional[_builtins.str]:
        """
        Private key for the GitOps agent. If provided authentication token will not be regenerated. Must be base64 encoded.
        """
        return pulumi.get(self, "private_key")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        """
        Project identifier of the GitOps agent.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def proxies(self) -> Optional[Sequence['outputs.GetGitopsAgentDeployYamlProxyResult']]:
        """
        Proxy settings for the GitOps agent.
        """
        return pulumi.get(self, "proxies")

    @_builtins.property
    @pulumi.getter(name="skipCrds")
    def skip_crds(self) -> Optional[_builtins.bool]:
        """
        Skip CRDs for the GitOps agent.
        """
        return pulumi.get(self, "skip_crds")

    @_builtins.property
    @pulumi.getter
    def yaml(self) -> _builtins.str:
        """
        The deployment manifest YAML of the GitOps agent.
        """
        return pulumi.get(self, "yaml")


class AwaitableGetGitopsAgentDeployYamlResult(GetGitopsAgentDeployYamlResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetGitopsAgentDeployYamlResult(
            account_id=self.account_id,
            argocd_settings=self.argocd_settings,
            ca_data=self.ca_data,
            id=self.id,
            identifier=self.identifier,
            namespace=self.namespace,
            org_id=self.org_id,
            private_key=self.private_key,
            project_id=self.project_id,
            proxies=self.proxies,
            skip_crds=self.skip_crds,
            yaml=self.yaml)


def get_gitops_agent_deploy_yaml(account_id: Optional[_builtins.str] = None,
                                 argocd_settings: Optional[Union['GetGitopsAgentDeployYamlArgocdSettingsArgs', 'GetGitopsAgentDeployYamlArgocdSettingsArgsDict']] = None,
                                 ca_data: Optional[_builtins.str] = None,
                                 identifier: Optional[_builtins.str] = None,
                                 namespace: Optional[_builtins.str] = None,
                                 org_id: Optional[_builtins.str] = None,
                                 private_key: Optional[_builtins.str] = None,
                                 project_id: Optional[_builtins.str] = None,
                                 proxies: Optional[Sequence[Union['GetGitopsAgentDeployYamlProxyArgs', 'GetGitopsAgentDeployYamlProxyArgsDict']]] = None,
                                 skip_crds: Optional[_builtins.bool] = None,
                                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetGitopsAgentDeployYamlResult:
    """
    Datasource for fetching a Harness Gitops Agent deployment manifest YAML.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    example = harness.platform.get_gitops_agent_deploy_yaml(identifier="identifier",
        account_id="account_id",
        project_id="project_id",
        org_id="org_id",
        namespace="namespace")
    ```


    :param _builtins.str account_id: Account identifier of the GitOps agent.
    :param Union['GetGitopsAgentDeployYamlArgocdSettingsArgs', 'GetGitopsAgentDeployYamlArgocdSettingsArgsDict'] argocd_settings: Argocd settings for the GitOps agent. Values set here will be overridden by the values set in the argocd settings in case of complete installation of agent + argocd. Each param contains as a description about what it will enable.
    :param _builtins.str ca_data: CA data of the GitOps agent, base64 encoded content of ca chain.
    :param _builtins.str identifier: Identifier of the GitOps agent.
    :param _builtins.str namespace: The kubernetes namespace where the agent is installed.
    :param _builtins.str org_id: Organization identifier of the GitOps agent.
    :param _builtins.str private_key: Private key for the GitOps agent. If provided authentication token will not be regenerated. Must be base64 encoded.
    :param _builtins.str project_id: Project identifier of the GitOps agent.
    :param Sequence[Union['GetGitopsAgentDeployYamlProxyArgs', 'GetGitopsAgentDeployYamlProxyArgsDict']] proxies: Proxy settings for the GitOps agent.
    :param _builtins.bool skip_crds: Skip CRDs for the GitOps agent.
    """
    __args__ = dict()
    __args__['accountId'] = account_id
    __args__['argocdSettings'] = argocd_settings
    __args__['caData'] = ca_data
    __args__['identifier'] = identifier
    __args__['namespace'] = namespace
    __args__['orgId'] = org_id
    __args__['privateKey'] = private_key
    __args__['projectId'] = project_id
    __args__['proxies'] = proxies
    __args__['skipCrds'] = skip_crds
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getGitopsAgentDeployYaml:getGitopsAgentDeployYaml', __args__, opts=opts, typ=GetGitopsAgentDeployYamlResult).value

    return AwaitableGetGitopsAgentDeployYamlResult(
        account_id=pulumi.get(__ret__, 'account_id'),
        argocd_settings=pulumi.get(__ret__, 'argocd_settings'),
        ca_data=pulumi.get(__ret__, 'ca_data'),
        id=pulumi.get(__ret__, 'id'),
        identifier=pulumi.get(__ret__, 'identifier'),
        namespace=pulumi.get(__ret__, 'namespace'),
        org_id=pulumi.get(__ret__, 'org_id'),
        private_key=pulumi.get(__ret__, 'private_key'),
        project_id=pulumi.get(__ret__, 'project_id'),
        proxies=pulumi.get(__ret__, 'proxies'),
        skip_crds=pulumi.get(__ret__, 'skip_crds'),
        yaml=pulumi.get(__ret__, 'yaml'))
def get_gitops_agent_deploy_yaml_output(account_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                        argocd_settings: Optional[pulumi.Input[Optional[Union['GetGitopsAgentDeployYamlArgocdSettingsArgs', 'GetGitopsAgentDeployYamlArgocdSettingsArgsDict']]]] = None,
                                        ca_data: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                        identifier: Optional[pulumi.Input[_builtins.str]] = None,
                                        namespace: Optional[pulumi.Input[_builtins.str]] = None,
                                        org_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                        private_key: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                        project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                        proxies: Optional[pulumi.Input[Optional[Sequence[Union['GetGitopsAgentDeployYamlProxyArgs', 'GetGitopsAgentDeployYamlProxyArgsDict']]]]] = None,
                                        skip_crds: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetGitopsAgentDeployYamlResult]:
    """
    Datasource for fetching a Harness Gitops Agent deployment manifest YAML.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    example = harness.platform.get_gitops_agent_deploy_yaml(identifier="identifier",
        account_id="account_id",
        project_id="project_id",
        org_id="org_id",
        namespace="namespace")
    ```


    :param _builtins.str account_id: Account identifier of the GitOps agent.
    :param Union['GetGitopsAgentDeployYamlArgocdSettingsArgs', 'GetGitopsAgentDeployYamlArgocdSettingsArgsDict'] argocd_settings: Argocd settings for the GitOps agent. Values set here will be overridden by the values set in the argocd settings in case of complete installation of agent + argocd. Each param contains as a description about what it will enable.
    :param _builtins.str ca_data: CA data of the GitOps agent, base64 encoded content of ca chain.
    :param _builtins.str identifier: Identifier of the GitOps agent.
    :param _builtins.str namespace: The kubernetes namespace where the agent is installed.
    :param _builtins.str org_id: Organization identifier of the GitOps agent.
    :param _builtins.str private_key: Private key for the GitOps agent. If provided authentication token will not be regenerated. Must be base64 encoded.
    :param _builtins.str project_id: Project identifier of the GitOps agent.
    :param Sequence[Union['GetGitopsAgentDeployYamlProxyArgs', 'GetGitopsAgentDeployYamlProxyArgsDict']] proxies: Proxy settings for the GitOps agent.
    :param _builtins.bool skip_crds: Skip CRDs for the GitOps agent.
    """
    __args__ = dict()
    __args__['accountId'] = account_id
    __args__['argocdSettings'] = argocd_settings
    __args__['caData'] = ca_data
    __args__['identifier'] = identifier
    __args__['namespace'] = namespace
    __args__['orgId'] = org_id
    __args__['privateKey'] = private_key
    __args__['projectId'] = project_id
    __args__['proxies'] = proxies
    __args__['skipCrds'] = skip_crds
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getGitopsAgentDeployYaml:getGitopsAgentDeployYaml', __args__, opts=opts, typ=GetGitopsAgentDeployYamlResult)
    return __ret__.apply(lambda __response__: GetGitopsAgentDeployYamlResult(
        account_id=pulumi.get(__response__, 'account_id'),
        argocd_settings=pulumi.get(__response__, 'argocd_settings'),
        ca_data=pulumi.get(__response__, 'ca_data'),
        id=pulumi.get(__response__, 'id'),
        identifier=pulumi.get(__response__, 'identifier'),
        namespace=pulumi.get(__response__, 'namespace'),
        org_id=pulumi.get(__response__, 'org_id'),
        private_key=pulumi.get(__response__, 'private_key'),
        project_id=pulumi.get(__response__, 'project_id'),
        proxies=pulumi.get(__response__, 'proxies'),
        skip_crds=pulumi.get(__response__, 'skip_crds'),
        yaml=pulumi.get(__response__, 'yaml')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['GitOpsAgentArgs', 'GitOpsAgent']

@pulumi.input_type
class GitOpsAgentArgs:
    def __init__(__self__, *,
                 identifier: pulumi.Input[_builtins.str],
                 type: pulumi.Input[_builtins.str],
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 metadatas: Optional[pulumi.Input[Sequence[pulumi.Input['GitOpsAgentMetadataArgs']]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 operator: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a GitOpsAgent resource.
        :param pulumi.Input[_builtins.str] identifier: Identifier of the GitOps agent.
        :param pulumi.Input[_builtins.str] type: Default: "AGENT*TYPE*UNSET"
               Enum: "AGENT*TYPE*UNSET" "CONNECTED*ARGO*PROVIDER" "MANAGED*ARGO*PROVIDER"
        :param pulumi.Input[_builtins.str] account_id: Account identifier of the GitOps agent.
        :param pulumi.Input[_builtins.str] description: Description of the GitOps agent.
        :param pulumi.Input[Sequence[pulumi.Input['GitOpsAgentMetadataArgs']]] metadatas: Metadata of the agent.
        :param pulumi.Input[_builtins.str] name: Name of the GitOps agent.
        :param pulumi.Input[_builtins.str] operator: The Operator to use for the Harness GitOps agent. Enum: "ARGO" "FLAMINGO"
        :param pulumi.Input[_builtins.str] org_id: Organization identifier of the GitOps agent.
        :param pulumi.Input[_builtins.str] project_id: Project identifier of the GitOps agent.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] tags: Tags for the GitOps agents. These can be used to search or filter the GitOps agents.
        """
        pulumi.set(__self__, "identifier", identifier)
        pulumi.set(__self__, "type", type)
        if account_id is not None:
            warnings.warn("""This field is deprecated and will be removed in a future release.""", DeprecationWarning)
            pulumi.log.warn("""account_id is deprecated: This field is deprecated and will be removed in a future release.""")
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if metadatas is not None:
            pulumi.set(__self__, "metadatas", metadatas)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if operator is not None:
            pulumi.set(__self__, "operator", operator)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Input[_builtins.str]:
        """
        Identifier of the GitOps agent.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Input[_builtins.str]:
        """
        Default: "AGENT*TYPE*UNSET"
        Enum: "AGENT*TYPE*UNSET" "CONNECTED*ARGO*PROVIDER" "MANAGED*ARGO*PROVIDER"
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter(name="accountId")
    @_utilities.deprecated("""This field is deprecated and will be removed in a future release.""")
    def account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Account identifier of the GitOps agent.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the GitOps agent.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def metadatas(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['GitOpsAgentMetadataArgs']]]]:
        """
        Metadata of the agent.
        """
        return pulumi.get(self, "metadatas")

    @metadatas.setter
    def metadatas(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['GitOpsAgentMetadataArgs']]]]):
        pulumi.set(self, "metadatas", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the GitOps agent.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def operator(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Operator to use for the Harness GitOps agent. Enum: "ARGO" "FLAMINGO"
        """
        return pulumi.get(self, "operator")

    @operator.setter
    def operator(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "operator", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Organization identifier of the GitOps agent.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Project identifier of the GitOps agent.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        Tags for the GitOps agents. These can be used to search or filter the GitOps agents.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _GitOpsAgentState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 agent_token: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 metadatas: Optional[pulumi.Input[Sequence[pulumi.Input['GitOpsAgentMetadataArgs']]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 operator: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 prefixed_identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering GitOpsAgent resources.
        :param pulumi.Input[_builtins.str] account_id: Account identifier of the GitOps agent.
        :param pulumi.Input[_builtins.str] agent_token: Agent token to be used for authentication of the agent with Harness.
        :param pulumi.Input[_builtins.str] description: Description of the GitOps agent.
        :param pulumi.Input[_builtins.str] identifier: Identifier of the GitOps agent.
        :param pulumi.Input[Sequence[pulumi.Input['GitOpsAgentMetadataArgs']]] metadatas: Metadata of the agent.
        :param pulumi.Input[_builtins.str] name: Name of the GitOps agent.
        :param pulumi.Input[_builtins.str] operator: The Operator to use for the Harness GitOps agent. Enum: "ARGO" "FLAMINGO"
        :param pulumi.Input[_builtins.str] org_id: Organization identifier of the GitOps agent.
        :param pulumi.Input[_builtins.str] prefixed_identifier: Prefixed identifier of the GitOps agent. Agent identifier prefixed with scope of the agent
        :param pulumi.Input[_builtins.str] project_id: Project identifier of the GitOps agent.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] tags: Tags for the GitOps agents. These can be used to search or filter the GitOps agents.
        :param pulumi.Input[_builtins.str] type: Default: "AGENT*TYPE*UNSET"
               Enum: "AGENT*TYPE*UNSET" "CONNECTED*ARGO*PROVIDER" "MANAGED*ARGO*PROVIDER"
        """
        if account_id is not None:
            warnings.warn("""This field is deprecated and will be removed in a future release.""", DeprecationWarning)
            pulumi.log.warn("""account_id is deprecated: This field is deprecated and will be removed in a future release.""")
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if agent_token is not None:
            pulumi.set(__self__, "agent_token", agent_token)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if metadatas is not None:
            pulumi.set(__self__, "metadatas", metadatas)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if operator is not None:
            pulumi.set(__self__, "operator", operator)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if prefixed_identifier is not None:
            pulumi.set(__self__, "prefixed_identifier", prefixed_identifier)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter(name="accountId")
    @_utilities.deprecated("""This field is deprecated and will be removed in a future release.""")
    def account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Account identifier of the GitOps agent.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter(name="agentToken")
    def agent_token(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Agent token to be used for authentication of the agent with Harness.
        """
        return pulumi.get(self, "agent_token")

    @agent_token.setter
    def agent_token(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "agent_token", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the GitOps agent.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Identifier of the GitOps agent.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter
    def metadatas(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['GitOpsAgentMetadataArgs']]]]:
        """
        Metadata of the agent.
        """
        return pulumi.get(self, "metadatas")

    @metadatas.setter
    def metadatas(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['GitOpsAgentMetadataArgs']]]]):
        pulumi.set(self, "metadatas", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the GitOps agent.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def operator(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Operator to use for the Harness GitOps agent. Enum: "ARGO" "FLAMINGO"
        """
        return pulumi.get(self, "operator")

    @operator.setter
    def operator(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "operator", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Organization identifier of the GitOps agent.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="prefixedIdentifier")
    def prefixed_identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Prefixed identifier of the GitOps agent. Agent identifier prefixed with scope of the agent
        """
        return pulumi.get(self, "prefixed_identifier")

    @prefixed_identifier.setter
    def prefixed_identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "prefixed_identifier", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Project identifier of the GitOps agent.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        Tags for the GitOps agents. These can be used to search or filter the GitOps agents.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Default: "AGENT*TYPE*UNSET"
        Enum: "AGENT*TYPE*UNSET" "CONNECTED*ARGO*PROVIDER" "MANAGED*ARGO*PROVIDER"
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)


@pulumi.type_token("harness:platform/gitOpsAgent:GitOpsAgent")
class GitOpsAgent(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 metadatas: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GitOpsAgentMetadataArgs', 'GitOpsAgentMetadataArgsDict']]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 operator: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Resource for managing a Harness GitOps Agent.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        example = harness.platform.GitOpsAgent("example",
            identifier="identifier",
            account_id="account_id",
            project_id="project_id",
            org_id="org_id",
            name="name",
            type="MANAGED_ARGO_PROVIDER",
            metadatas=[{
                "namespace": "namespace",
                "high_availability": True,
            }])
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import an Account level Gitops Agent

        ```sh
        $ pulumi import harness:platform/gitOpsAgent:GitOpsAgent example <agent_id>
        ```

        Import an Org level Gitops Agent

        ```sh
        $ pulumi import harness:platform/gitOpsAgent:GitOpsAgent example <organization_id>/<agent_id>
        ```

        Import a Project level Gitops Agent

        ```sh
        $ pulumi import harness:platform/gitOpsAgent:GitOpsAgent example <organization_id>/<project_id>/<agent_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: Account identifier of the GitOps agent.
        :param pulumi.Input[_builtins.str] description: Description of the GitOps agent.
        :param pulumi.Input[_builtins.str] identifier: Identifier of the GitOps agent.
        :param pulumi.Input[Sequence[pulumi.Input[Union['GitOpsAgentMetadataArgs', 'GitOpsAgentMetadataArgsDict']]]] metadatas: Metadata of the agent.
        :param pulumi.Input[_builtins.str] name: Name of the GitOps agent.
        :param pulumi.Input[_builtins.str] operator: The Operator to use for the Harness GitOps agent. Enum: "ARGO" "FLAMINGO"
        :param pulumi.Input[_builtins.str] org_id: Organization identifier of the GitOps agent.
        :param pulumi.Input[_builtins.str] project_id: Project identifier of the GitOps agent.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] tags: Tags for the GitOps agents. These can be used to search or filter the GitOps agents.
        :param pulumi.Input[_builtins.str] type: Default: "AGENT*TYPE*UNSET"
               Enum: "AGENT*TYPE*UNSET" "CONNECTED*ARGO*PROVIDER" "MANAGED*ARGO*PROVIDER"
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GitOpsAgentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for managing a Harness GitOps Agent.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        example = harness.platform.GitOpsAgent("example",
            identifier="identifier",
            account_id="account_id",
            project_id="project_id",
            org_id="org_id",
            name="name",
            type="MANAGED_ARGO_PROVIDER",
            metadatas=[{
                "namespace": "namespace",
                "high_availability": True,
            }])
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import an Account level Gitops Agent

        ```sh
        $ pulumi import harness:platform/gitOpsAgent:GitOpsAgent example <agent_id>
        ```

        Import an Org level Gitops Agent

        ```sh
        $ pulumi import harness:platform/gitOpsAgent:GitOpsAgent example <organization_id>/<agent_id>
        ```

        Import a Project level Gitops Agent

        ```sh
        $ pulumi import harness:platform/gitOpsAgent:GitOpsAgent example <organization_id>/<project_id>/<agent_id>
        ```

        :param str resource_name: The name of the resource.
        :param GitOpsAgentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GitOpsAgentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 metadatas: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GitOpsAgentMetadataArgs', 'GitOpsAgentMetadataArgsDict']]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 operator: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GitOpsAgentArgs.__new__(GitOpsAgentArgs)

            __props__.__dict__["account_id"] = account_id
            __props__.__dict__["description"] = description
            if identifier is None and not opts.urn:
                raise TypeError("Missing required property 'identifier'")
            __props__.__dict__["identifier"] = identifier
            __props__.__dict__["metadatas"] = metadatas
            __props__.__dict__["name"] = name
            __props__.__dict__["operator"] = operator
            __props__.__dict__["org_id"] = org_id
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["tags"] = tags
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
            __props__.__dict__["agent_token"] = None
            __props__.__dict__["prefixed_identifier"] = None
        super(GitOpsAgent, __self__).__init__(
            'harness:platform/gitOpsAgent:GitOpsAgent',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[_builtins.str]] = None,
            agent_token: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            identifier: Optional[pulumi.Input[_builtins.str]] = None,
            metadatas: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GitOpsAgentMetadataArgs', 'GitOpsAgentMetadataArgsDict']]]]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            operator: Optional[pulumi.Input[_builtins.str]] = None,
            org_id: Optional[pulumi.Input[_builtins.str]] = None,
            prefixed_identifier: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
            type: Optional[pulumi.Input[_builtins.str]] = None) -> 'GitOpsAgent':
        """
        Get an existing GitOpsAgent resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: Account identifier of the GitOps agent.
        :param pulumi.Input[_builtins.str] agent_token: Agent token to be used for authentication of the agent with Harness.
        :param pulumi.Input[_builtins.str] description: Description of the GitOps agent.
        :param pulumi.Input[_builtins.str] identifier: Identifier of the GitOps agent.
        :param pulumi.Input[Sequence[pulumi.Input[Union['GitOpsAgentMetadataArgs', 'GitOpsAgentMetadataArgsDict']]]] metadatas: Metadata of the agent.
        :param pulumi.Input[_builtins.str] name: Name of the GitOps agent.
        :param pulumi.Input[_builtins.str] operator: The Operator to use for the Harness GitOps agent. Enum: "ARGO" "FLAMINGO"
        :param pulumi.Input[_builtins.str] org_id: Organization identifier of the GitOps agent.
        :param pulumi.Input[_builtins.str] prefixed_identifier: Prefixed identifier of the GitOps agent. Agent identifier prefixed with scope of the agent
        :param pulumi.Input[_builtins.str] project_id: Project identifier of the GitOps agent.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] tags: Tags for the GitOps agents. These can be used to search or filter the GitOps agents.
        :param pulumi.Input[_builtins.str] type: Default: "AGENT*TYPE*UNSET"
               Enum: "AGENT*TYPE*UNSET" "CONNECTED*ARGO*PROVIDER" "MANAGED*ARGO*PROVIDER"
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GitOpsAgentState.__new__(_GitOpsAgentState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["agent_token"] = agent_token
        __props__.__dict__["description"] = description
        __props__.__dict__["identifier"] = identifier
        __props__.__dict__["metadatas"] = metadatas
        __props__.__dict__["name"] = name
        __props__.__dict__["operator"] = operator
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["prefixed_identifier"] = prefixed_identifier
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["tags"] = tags
        __props__.__dict__["type"] = type
        return GitOpsAgent(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="accountId")
    @_utilities.deprecated("""This field is deprecated and will be removed in a future release.""")
    def account_id(self) -> pulumi.Output[_builtins.str]:
        """
        Account identifier of the GitOps agent.
        """
        return pulumi.get(self, "account_id")

    @_builtins.property
    @pulumi.getter(name="agentToken")
    def agent_token(self) -> pulumi.Output[_builtins.str]:
        """
        Agent token to be used for authentication of the agent with Harness.
        """
        return pulumi.get(self, "agent_token")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description of the GitOps agent.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Output[_builtins.str]:
        """
        Identifier of the GitOps agent.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter
    def metadatas(self) -> pulumi.Output[Optional[Sequence['outputs.GitOpsAgentMetadata']]]:
        """
        Metadata of the agent.
        """
        return pulumi.get(self, "metadatas")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the GitOps agent.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def operator(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The Operator to use for the Harness GitOps agent. Enum: "ARGO" "FLAMINGO"
        """
        return pulumi.get(self, "operator")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Organization identifier of the GitOps agent.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="prefixedIdentifier")
    def prefixed_identifier(self) -> pulumi.Output[_builtins.str]:
        """
        Prefixed identifier of the GitOps agent. Agent identifier prefixed with scope of the agent
        """
        return pulumi.get(self, "prefixed_identifier")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Project identifier of the GitOps agent.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, _builtins.str]]]:
        """
        Tags for the GitOps agents. These can be used to search or filter the GitOps agents.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Output[_builtins.str]:
        """
        Default: "AGENT*TYPE*UNSET"
        Enum: "AGENT*TYPE*UNSET" "CONNECTED*ARGO*PROVIDER" "MANAGED*ARGO*PROVIDER"
        """
        return pulumi.get(self, "type")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['AzureArgs', 'Azure']

@pulumi.input_type
class AzureArgs:
    def __init__(__self__, *,
                 client_id: pulumi.Input[_builtins.str],
                 key: pulumi.Input[_builtins.str],
                 tenant_id: pulumi.Input[_builtins.str],
                 environment_type: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Azure resource.
        :param pulumi.Input[_builtins.str] client_id: The client id for the Azure application
        :param pulumi.Input[_builtins.str] key: The Name of the Harness secret containing the key for the Azure application
        :param pulumi.Input[_builtins.str] tenant_id: The tenant id for the Azure application
        :param pulumi.Input[_builtins.str] environment_type: The type of environment. Valid options are [AZURE AZURE*US*GOVERNMENT]
        :param pulumi.Input[_builtins.str] name: The name of the cloud provider.
        """
        pulumi.set(__self__, "client_id", client_id)
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "tenant_id", tenant_id)
        if environment_type is not None:
            pulumi.set(__self__, "environment_type", environment_type)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter(name="clientId")
    def client_id(self) -> pulumi.Input[_builtins.str]:
        """
        The client id for the Azure application
        """
        return pulumi.get(self, "client_id")

    @client_id.setter
    def client_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "client_id", value)

    @_builtins.property
    @pulumi.getter
    def key(self) -> pulumi.Input[_builtins.str]:
        """
        The Name of the Harness secret containing the key for the Azure application
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "key", value)

    @_builtins.property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> pulumi.Input[_builtins.str]:
        """
        The tenant id for the Azure application
        """
        return pulumi.get(self, "tenant_id")

    @tenant_id.setter
    def tenant_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "tenant_id", value)

    @_builtins.property
    @pulumi.getter(name="environmentType")
    def environment_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of environment. Valid options are [AZURE AZURE*US*GOVERNMENT]
        """
        return pulumi.get(self, "environment_type")

    @environment_type.setter
    def environment_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "environment_type", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the cloud provider.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _AzureState:
    def __init__(__self__, *,
                 client_id: Optional[pulumi.Input[_builtins.str]] = None,
                 environment_type: Optional[pulumi.Input[_builtins.str]] = None,
                 key: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 tenant_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Azure resources.
        :param pulumi.Input[_builtins.str] client_id: The client id for the Azure application
        :param pulumi.Input[_builtins.str] environment_type: The type of environment. Valid options are [AZURE AZURE*US*GOVERNMENT]
        :param pulumi.Input[_builtins.str] key: The Name of the Harness secret containing the key for the Azure application
        :param pulumi.Input[_builtins.str] name: The name of the cloud provider.
        :param pulumi.Input[_builtins.str] tenant_id: The tenant id for the Azure application
        """
        if client_id is not None:
            pulumi.set(__self__, "client_id", client_id)
        if environment_type is not None:
            pulumi.set(__self__, "environment_type", environment_type)
        if key is not None:
            pulumi.set(__self__, "key", key)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if tenant_id is not None:
            pulumi.set(__self__, "tenant_id", tenant_id)

    @_builtins.property
    @pulumi.getter(name="clientId")
    def client_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The client id for the Azure application
        """
        return pulumi.get(self, "client_id")

    @client_id.setter
    def client_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "client_id", value)

    @_builtins.property
    @pulumi.getter(name="environmentType")
    def environment_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of environment. Valid options are [AZURE AZURE*US*GOVERNMENT]
        """
        return pulumi.get(self, "environment_type")

    @environment_type.setter
    def environment_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "environment_type", value)

    @_builtins.property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Name of the Harness secret containing the key for the Azure application
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "key", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the cloud provider.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The tenant id for the Azure application
        """
        return pulumi.get(self, "tenant_id")

    @tenant_id.setter
    def tenant_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tenant_id", value)


@pulumi.type_token("harness:cloudprovider/azure:Azure")
class Azure(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 client_id: Optional[pulumi.Input[_builtins.str]] = None,
                 environment_type: Optional[pulumi.Input[_builtins.str]] = None,
                 key: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 tenant_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Resource for creating an Azure cloud provider. This resource uses the config-as-code API's. When updating the `name` or `path` of this resource you should typically also set the `create_before_destroy = true` lifecycle setting.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        default = harness.get_secret_manager(default=True)
        azure_key = harness.EncryptedText("azure_key",
            name="azure_key",
            value="<AZURE_KEY>",
            secret_manager_id=default.id)
        azure = harness.cloudprovider.Azure("azure",
            name="azure",
            client_id="<AZURE_CLIENT_ID>",
            tenant_id="<AZURE_TENANT_ID>",
            key=azure_key.name)
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import using the Harness azure cloud provider id.

        ```sh
        $ pulumi import harness:cloudprovider/azure:Azure example <provider_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] client_id: The client id for the Azure application
        :param pulumi.Input[_builtins.str] environment_type: The type of environment. Valid options are [AZURE AZURE*US*GOVERNMENT]
        :param pulumi.Input[_builtins.str] key: The Name of the Harness secret containing the key for the Azure application
        :param pulumi.Input[_builtins.str] name: The name of the cloud provider.
        :param pulumi.Input[_builtins.str] tenant_id: The tenant id for the Azure application
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AzureArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating an Azure cloud provider. This resource uses the config-as-code API's. When updating the `name` or `path` of this resource you should typically also set the `create_before_destroy = true` lifecycle setting.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        default = harness.get_secret_manager(default=True)
        azure_key = harness.EncryptedText("azure_key",
            name="azure_key",
            value="<AZURE_KEY>",
            secret_manager_id=default.id)
        azure = harness.cloudprovider.Azure("azure",
            name="azure",
            client_id="<AZURE_CLIENT_ID>",
            tenant_id="<AZURE_TENANT_ID>",
            key=azure_key.name)
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import using the Harness azure cloud provider id.

        ```sh
        $ pulumi import harness:cloudprovider/azure:Azure example <provider_id>
        ```

        :param str resource_name: The name of the resource.
        :param AzureArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AzureArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 client_id: Optional[pulumi.Input[_builtins.str]] = None,
                 environment_type: Optional[pulumi.Input[_builtins.str]] = None,
                 key: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 tenant_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AzureArgs.__new__(AzureArgs)

            if client_id is None and not opts.urn:
                raise TypeError("Missing required property 'client_id'")
            __props__.__dict__["client_id"] = client_id
            __props__.__dict__["environment_type"] = environment_type
            if key is None and not opts.urn:
                raise TypeError("Missing required property 'key'")
            __props__.__dict__["key"] = key
            __props__.__dict__["name"] = name
            if tenant_id is None and not opts.urn:
                raise TypeError("Missing required property 'tenant_id'")
            __props__.__dict__["tenant_id"] = tenant_id
        super(Azure, __self__).__init__(
            'harness:cloudprovider/azure:Azure',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            client_id: Optional[pulumi.Input[_builtins.str]] = None,
            environment_type: Optional[pulumi.Input[_builtins.str]] = None,
            key: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            tenant_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'Azure':
        """
        Get an existing Azure resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] client_id: The client id for the Azure application
        :param pulumi.Input[_builtins.str] environment_type: The type of environment. Valid options are [AZURE AZURE*US*GOVERNMENT]
        :param pulumi.Input[_builtins.str] key: The Name of the Harness secret containing the key for the Azure application
        :param pulumi.Input[_builtins.str] name: The name of the cloud provider.
        :param pulumi.Input[_builtins.str] tenant_id: The tenant id for the Azure application
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AzureState.__new__(_AzureState)

        __props__.__dict__["client_id"] = client_id
        __props__.__dict__["environment_type"] = environment_type
        __props__.__dict__["key"] = key
        __props__.__dict__["name"] = name
        __props__.__dict__["tenant_id"] = tenant_id
        return Azure(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="clientId")
    def client_id(self) -> pulumi.Output[_builtins.str]:
        """
        The client id for the Azure application
        """
        return pulumi.get(self, "client_id")

    @_builtins.property
    @pulumi.getter(name="environmentType")
    def environment_type(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The type of environment. Valid options are [AZURE AZURE*US*GOVERNMENT]
        """
        return pulumi.get(self, "environment_type")

    @_builtins.property
    @pulumi.getter
    def key(self) -> pulumi.Output[_builtins.str]:
        """
        The Name of the Harness secret containing the key for the Azure application
        """
        return pulumi.get(self, "key")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the cloud provider.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> pulumi.Output[_builtins.str]:
        """
        The tenant id for the Azure application
        """
        return pulumi.get(self, "tenant_id")

